#
# spec file for package mstflint
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define extra_version -1

Name:           mstflint
Version:        4.25.0
Release:        2.1
Summary:        Mellanox Firmware Burning and Diagnostics Tools
License:        BSD-2-Clause OR GPL-2.0-only
Group:          System/Console
URL:            http://www.openfabrics.org
Obsoletes:      mstflint-devel < %{version}
Source:         https://github.com/Mellanox/mstflint/releases/download/v%{version}%{extra_version}/mstflint-%{version}%{extra_version}.tar.gz
Patch1:         Remove-date-time-info-from-build.patch
Patch4:         Fix-gcc7-and-gcc8.patch
Patch5:         fix-race-condition-during-install.patch
Patch6:         PIE.patch
BuildRequires:  gcc-c++
BuildRequires:  infiniband-diags-devel
BuildRequires:  libibverbs-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains a burning tool and diagnostic tools for Mellanox
manufactured HCA/NIC cards. It also provides access to the relevant
source code. Please see the file LICENSE for licensing details.

This package is based on a subset of the Mellanox Firmware Tools (MFT)
package. For a full documentation of the MFT package, please refer to
the downloads page at the Mellanox web site.

%prep
%autosetup -p0

%build
./autogen.sh
%configure
make %{?_smp_mflags} CFLAGS="%{optflags} -I. -fno-exceptions"

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm -rf %{buildroot}%{_includedir}/mstflint
rm -rf  %{buildroot}%{_libdir}/mstflint/*.a
rm -rf  %{buildroot}%{_libdir}/*.a
rm -rf %{buildroot}%{_bindir}/hca_self_test.ofed

%files
%defattr(-, root, root)
%doc README
%license LICENSE COPYING
%{_bindir}/mstconfig
%{_bindir}/mstcongestion
%{_bindir}/mstflint
%{_bindir}/mstfwreset
%{_bindir}/mstmcra
%{_bindir}/mstmread
%{_bindir}/mstmtserver
%{_bindir}/mstmwrite
%{_bindir}/mstprivhost
%{_bindir}/mstregdump
%{_bindir}/mstresourcedump
%{_bindir}/mstresourceparse
%{_bindir}/mstvpd
%{_bindir}/mstfwtrace
%{_mandir}/man1/*.1%{ext_man}
%{_libdir}/mstflint/
%{_datadir}/mstflint/

%changelog
* Thu Feb 22 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Sep 28 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to 4.25.0
  https://github.com/Mellanox/mstflint/files/12317054/MSTFLINT.Package.-Firmware.Burning.and.Diagnostics.Tools.Documentation.v4.25.0.pdf
- Refresh fix-race-condition-during-install.patch to handle new race conditions
* Mon Jul 17 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to 4.24.0
  https://github.com/Mellanox/mstflint/releases/download/v4.24.0-1/MSTFLINT.Package.-Firmware.Burning.and.Diagnostics.Tools.Documentation.v4.24.0.pdf
- Refresh fix-race-condition-during-install.patch to handle new race conditions
* Wed Jun  7 2023 pgajdos@suse.com
- version update to 4.23.0
  https://github.com/Mellanox/mstflint/releases/download/v4.23.0-1/MSTFLINT.Package.-Firmware.Burning.and.Diagnostics.Tools.Documentation.v4.23.0.pdf
- modified patches
  %% PIE.patch (refreshed)
* Mon Oct 17 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Updated fix-race-condition-during-install.patch to fix another
  race condition during install
* Fri Sep 30 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v4.21.0-1 (jsc#PED-911, jsc#PED-1188)
  - Generic
  - Added support for NVIDIA ConnectX-7 adapter cards.
  - Added additional Flash support for ConnectX-4 Lx and ConnectX-5 adapter cards.
  - Python 2.x - Python 2.x is now end-of-life and no longer supported by MFT.
  - mstfwreset
  - For some configuration changes done using mstconfig, PCI rescan by the user is required.
  - Added a new reset-type ("NIC only reset") to mstfwreset which is applicable only
    to SmartNIC devices. The new reset-type is also the new default for SmartNIC devices.
    In case of reset-type is set to "NIC only reset", mstfwreset will not reset the internal host.
  - mstflint
  - Querying Vendor Specific Firmware Information from an Nvidia AOC / Transceiver Querying
    a firmware cable transceiver is now done using the "mstflint" tool.
  - cable/transceivers burning commands provide now validation and extract version from the image files.
  - Modified the output of the PCIe link information, removed the device status filed.
  - When downgrading to a firmware version that does not support the flash type of
    the device, mstflint will present the user a clear error of such scenario.
  - mlxconfig
  - Enable the users to apply token via MTUSB connected device.
  - mstresourceparse
  - mstresourceparse will present the union fields according to the selector.
    Unions that do not have a selector, will be presented with all the fields as before.
  - mstresourcedump
  - mstresourcedump tool now runs ~10X faster in mem mode with output to binary file.
  - Updated the "--virtual-hca-id" value output to be in a hexadecimal format.
  - Memory-Mode, data field is now transferred via memory instead of the resource-dump register.
  - mstlink
  - Removed irrelevant "eye" info fields in the output of the "show eye" command for PCIe links.
  - Removed the device status field from the PCIe info section.
  - Added support for "show_eye" command for ConnectX-7 over PCIe links.
  - Re-formatted the serdes Tx parameter layout in the "show_sedes_tx" command.
  - Added support for the PRBS test mode of Active/Optical CMIS modules.
  - Added support for additional configuration flags of the module control parameters.
  - Added support for new PRBS TX/RX patterns (--tx_prbs <tx_prbs_mode> & --rx_prbs <rx_prbs_mode>).
  - Added new show counters for 16nm devices. To see them run the "show_counter" command.
  - Extended the list of the cable information received for 16nm devices when running the "show_module" command.
  - Extended the information collection for 7nm and 16nm devices. See "--amber_collect" flag.
  - Extended the list of the cable information (LOL, LOS, FSM, and module status)
    for CMIS when running the "show_module" command.
  - mstdump
  - Added an optional parameter of the CSV path (-c | --csv)
    which loads the provides the CSV from a fixed location as a DB instead of the default one.
  - mstprivhost
  - Added a new flag to query all hosts status from the embedded Arm side for Multi-host systems.
- Refresh patches against latest sources:
  - Remove-date-time-info-from-build.patch
  - Fix-gcc7-and-gcc8.patch
* Wed Jul  7 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v4.17.0-1 (jsc#SLE-19261)
  - Anti-rollback Protection
  - Enabled Anti-rollback protection to prevent old vulnerable firmware
    versions from being flashed to the device
  - mstlink tool
  - Added support for DSFP modules
  - Parallel Firmware Burning (DMA Burning)
  - Added support for parallel firmware burning.
- Refresh PIE.patch against latest sources
* Tue May 25 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Link as position independent executables (bsc#1184124).
  - Added PIE.patch
* Wed Apr  7 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v4.16.0-2
  - mstlink tool
  - Added support for PCIe eye grade scan
  - Enabled margin scan on Network links
  - Enabled querying the current host configuration using the "q | query" flag
  - mstconfig tool
  - fixed database
  - fixed several bugs
- Refresh patches against latest sources:
  - Remove-date-time-info-from-build.patch
  - Fix-gcc7-and-gcc8.patch
  - fix-race-condition-during-install.patch
* Wed Sep 23 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v4.15.0-1 (jsc#SLE-15968)
  - New Supported Devices
  - ConnectX-6Lx adapter cards support.
  - BlueField-2 adapter cards support.
  - mstconfig tool
  - QOS ets configuration ConnectX-4 LX 25NIC failed when enabled VFs > 21
  - Network programmability (Dynamic Flex Parse) Packet classification on
    eCPRI header on receive with DPDK
  - Improved BlueField NVMf Performance when working in 4K block size
    [BlueField SmartNIC] Support full virtio-net PCI device emulation +
  Device Hot Plug - BareMetal case GA
  - ConnectX-6 SHARPv2 to achieve line-rate performance
  - New Feature - BOOT_INTERRUPT_DIS parameter was added to mlxconfig.
    When TRUE, legacy interrupts should not be used for receive/transmit indication.
    Polling should be used instead.
  - mstdump tool
  - Fixed an issue that caused mstflint to print garbage messages.
    To fix the bug, the new kernel module should be recompiled and loaded
  - mstreg tool
    [software steering, ASAP^2, Connection Tracking] adding DP_HASH support
  - Virtual output Queuing - exposing descriptors
  - New Feature - Increased the registry keys the tool supports and now it exposes the full PRM.
  - For additional information, refer to the PRM.
  - mstlink tool
  - need mstlink to support TX SerDes set --database at Quantum and Spectrum-2
  - QSFP DD + CMIS
  - mstlink - support for 400G
  - mstlink to enforce PRBS at host-management and/ or multi-host systems
  - mstlink - add support to configure PRBS
  - Read/Write SerDes Tx taps with new SLTP register - mstlink
  - Fix the return bad status of SLTP according to the new return values
  - New Feature - HDR lane rate is now supported when in Pseudorandom Binary Sequence (PRBS) mode.
  - New Feature - Added support for switching between NRZ/PAM4 speeds for new devices that support
  - HDR/200G speeds (ConnectX-6, ConnectX-6 Dx, Mellanox Quantum, Mellanox Spectrum 2).
  - mstfwreset tool
  - handling mstfwreset on SN in different modes
  - mstflint tool
    [Secure Boot][BlueField-2] EFUSE keys burn tool (Arm OS) for RSA Keys and MKEK
  - Support HPCC in CX6Dx
  - Add life cycle, secure boot, recovery indications to the flint query full command
  - New Feature - Enables the user to insert information manually to the flash on components
    such as MFG/DEV GUID/MAC when no information exists after the burn process using the command
    "mstflint -d \<device\> sg \<guid\>".
    If the information is not inserted manually, the existing GUID/MAC
  - information will be used instead.
  - New Feature - Enables the user to query the MFA2 file using a PSID.
  - mstresourcedump tool
  - MSTResoruceDump new tool: Build a dump passer tool for parsing resource dumps
  - Added support for "--virtual-hca-id" command. Now the tool can provide info on the virtual HCA
    (host channel adapter, NIC) ID.
* Fri Jan 24 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v4.13.3-2
  - ConnectX-6DX adapter cards GA support.
  - mstflint tool
  - New feature - Burning MFA2 images. Enables the user to extract (i.e. unzip)
    4MB images from MFA2 archive, that matches the device type and device PSIB.
  - New feature - Verifying MFA2 Archive. Enables the user to verify a given MFA2
    archive contains the image that matches the given device.
  - New feature - Verifying firmware image on a device which operates in livefish mode by
    comparing it with an existing binary firmware file.
  - Added image-reactivation feature which re-assigns the image signature to the
    previous image (in case the new image is faulty) enabling "fwreset" functionality
    or to burn a new image.
  - mstresourcedump tool
  - New mstresourcedump tool added to extracts and prints data segments generated
    by the firmware. The dump output is used by Mellanox for debug and troubleshooting.
  - mstfwreset tool
  - Added support for Socket Direct devices in the mstfwreset tool.
  - Added save/restore ATS PCIE capability.
  - Added support for Live-Patch in ConnectX-5.
  - Added a new reset option (reset-type) to the reset command of mstfwreset.
    The user can see the supported reset-types by using the query command.
  - mstlink tool
  - New feature - Using --json flag formats the output of the tool including all
    options & commands in JSON format and prints it.
  - Added support for reading the "Link Downed Counter" and "Link Error Recovery Counter"
    in the mstlink utility when using InfiniBand protocol only.
  - Added support for HDR PCIe grades in the EYE Opening Info in the mstlink utility.
  - Added a new flag (show links) to define the valid PCIe links.
  - Displays and configures port related data at the physical layer.
  - mstconfig tool
  - Added the ATS_ENABLED TLV param. When set to TRUE, the device will support Address
    Translation Service (ATS).
  - Added the VF_VPD_ENABLE parameter to mstconfig. When set, the VPD capability
    is exposed to Virtual Functions.
  - mstarchive tool
  - Added support for MFA2 query using the mstarchive tool.
  - mstfwtrace tool
  - Extracts and prints trace messages generated by the firmware of 5th generation devices.
    This tool supports secure firmware flow only.
  - mstreg tool
  - Exposes supported access registers, and allows users to obtain information
    regarding the registers fields and attributes, and to set and get data with
    a specific register.
  - mstfwmanager tool
  - Supports listing the contents of images archive. When running this command the tool
    will list all firmware images within this PLDM package for each image it displays.
* Thu Sep  5 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v4.11.0-5 (bsc#1136328)
  - Build related changes
  - Disabled -Werror compiler flag
  - Added the option to choose local system libraries if available in the machine
  - Enhanced python 3 compatibility
  - Removed python shebangs from the scripts
  - Fixed multiple rpmbuild issues
  - Added --enable-all-static configure flag that allows compilation of static executables, when the the option is supported by the compiler
  - All python scripts were aligned to unix encoding
  - Fixed multiple builds and compilation issues
  - mstprivhost tool
  - Added mstprivhost tool to set host privilege configurations
  - mstflint tool
  - Added missing Rom info attribute for legacy FW qq query
  - Fixed query timeout when device is locked
  - Renamed former --next_boot_fw_ver to --flashed_version flag. This flag queries the flashed version.
  - Note that the previous flag is supported to keep compatibility.
  - Fixed an issue with FW upgrade on ConnectX-5 EN
  - mstregdup tool
  - Fixed segfault
  - mstconfig
  - Added new params:
  - mstfwtrace
  - Added fwtracer: in this release, this tool supports secure FW flow only
  - libibmad
  - Added support for libibmad 12 in addition to 5
  - Python tools
  - Fixed Python wrapper to work properly in multiple OSes and multiple Python versions
  - Added adb generic tools
  - Added mstreg tool: To enable this option please use "--enable-adb-genaric-tools" flag
  - mstarchive
  - Added return values
  - Fixed an issue in the MFA2's header minor and subminor versions
- Drop patches that were fixed upstream:
  - Add-armv6-and-armv7-support.patch
  - Add-s390-s390x-support.patch
- Refresh patchest against latest sources:
  - Fix-gcc7-and-gcc8.patch
  - Remove-date-time-info-from-build.patch
  - fix-race-condition-during-install.patch
* Fri Mar 29 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Add missing python helpers to the package (bsc#1103497)
* Wed Feb 13 2019 nmoreychaisemartin@suse.com
- Update to v4.11.0-3 (bsc#1103497)
  - Added option to query only flashed FW version, which reduces the CPU usage during the query.
    To use this option you should use "--next_boot_fw_ver" flag.
  - Fixed issue of missing information during query.
  - Added support for python 3.
  - Added option to reduce cpu utilization with "--low_cpu" flag.
  - Added compatibility to 1.1.X version, in addition to previously supported 1.0.2 version.
  - Added support for Mellanox Quantum switch systems and
    ConnectX-6 Ready adapter cards.
  - mstarchive tool
    The mstarchive tool allows the user to create a file with the mfa2 extension.
    The new file contains several binary files of a given firmware for
    different adapter cards.
  - mstprivhost
    The ability to restrict the hosts from configuring the NIC.
    Meaning, only the Arm side will have the privilege to configure the NIC.
    Note: This utility is supported in BlueField devices only.
  - mstconfig in BlueField
    Enables the user to manage (grand/restrict) mlxconfig configuration
    privileges for BlueField Arm systems.
- Refresh patchest against latest sources:
  - Add-armv6-and-armv7-support.patch
  - Add-s390-s390x-support.patch
  - Fix-gcc7-and-gcc8.patch
  - Remove-date-time-info-from-build.patch
  - fix-race-condition-during-install.patch
- Drop Fixed-licenses-of-files.patch as it was merged upstream
* Mon Nov 19 2018 nmoreychaisemartin@suse.com
- Add Fixed-licenses-of-files.patch from upstream that
  fixes license issues (bsc#1086923)
* Mon Oct 15 2018 nmoreychaisemartin@suse.com
- Update to v4.10.0-3 (fate#325998)
  - Added mstcongestion
- Add fix-race-condition-during-install.patch
  to fix install on parallel builds
* Tue Jul 31 2018 nmoreychaisemartin@suse.com
- Update to v4.10.0-2
  - mstfwreset not supported
  - mstflint now handles all the burn parameters when MCC
    is enabled and displays the secure-FW CS tokens.
  - mstconfig
  - Added the option to query partial parameters
  - Added the following new parameters:
    FLEX_PARSER_PROFILE_ENABLE
    ECPF_ESWITCH_MANAGER
    ECPF_PAGE_SUPPLIER
    SAFE_MODE_ENABLE
    SAFE_MODE_THERSHOLD
    BOOT_UNDI_NETWORK_WAIT
  - Fixed bug in firmware burning flow
- Refresh patchest against latest sources:
  - Remove-date-time-info-from-build.patch
  - Add-s390-s390x-support.patch
  - Add-armv6-and-armv7-support.patch
  - Fix-gcc7-and-gcc8.patch
* Mon Jun 18 2018 nmoreychaisemartin@suse.com
- Update patches to fit science:HPC worflow
  - Remove old format patches
  - mstflint-4.4.0-implicit-declaration.patch
  - mstflint-4.4.0-no-date-time.patch
  - mstflint-armv6_arch.patch
  - mstflint-armv7_arch.patch
  - mstflint-gcc7.patch
  - mstflint-s390_arch.patch
  - Replaced with new format patches
  - Remove-date-time-info-from-build.patch
  - Add-s390-s390x-support.patch
  - Add-armv6-and-armv7-support.patch
  - Fix-gcc7-and-gcc8.patch
  - Patch was updated to also fix Gcc8 compilation issues
  - Drop obsolete patch
  - mstfint-mtcr_ul_no_static_lib.patch
- Update to v4.9.0-3
  - No release notes available
* Sun Mar 25 2018 kasimir_@outlook.de
- Add mstflint-armv6_arch.patch to support build on armv6l
* Tue Mar 20 2018 nmoreychaisemartin@suse.com
- Update to v4.9.0-1
  * mstfwreset
  * Added support for a hot swap (or hot plug) of the PCIe slot.
  * Secure Firmware Update
  * Added support for Secure Firmware Update to ConnectX-4 adapter cards.
  * Enabled signing the package with an RSA 4096 bit keys.
  * Added support for setting the GUIDs when Secure Firmware Update is enabled.
  * mstconfig
  * Added the following mstconfig configuration parameters:
  * AUTO_RELOAD
  * DRIVER_SETTINGS
  * EXP_ROM_PXE_ENABLE
  * EXP_ROM_UEFI_ARM_ENABLE
  * EXP_ROM_UEFI_X86_ENABLE
  * INTERNAL_CPU_MODEL
  * IPV4
  * IPV6
  * PCI_DATA_WR_ORDERING_MODE
  * PXE_UNDI
  * STATUS_UPDATE
  * TCP
  * TCPIP
  * TRACER_ENABLE
  * mstflint
  * Added support for FreeBSD with BSD license.
  * Secure Boot
  * Added support for secure boot to ConnectX-3 adapter cards.
* Thu Nov  9 2017 nmoreychaisemartin@suse.com
- Update to v4.8.0-2
  * Drop proprietary Mellanox file
* Tue Oct 31 2017 nmoreychaisemartin@suse.com
- Update to v4.8.0-1, No info of changes available (bsc#1046293, fate#322949)
- Update mstflint-gcc7.patch to the latest sources
* Wed Aug  9 2017 nmoreychaisemartin@suse.com
- Update to v4.7.0-1, No info of changes available
* Fri Jun 23 2017 nmoreychaisemartin@suse.com
- Replace dependency from libibmad-devel to infiniband-diags-devel
* Tue May 30 2017 nmoreychaisemartin@suse.com
- Add mstflint-gcc7.patch for GCC7 support
* Thu May 18 2017 nmoreychaisemartin@suse.com
- Add mstflint-armv7_arch.patch to support build on armv7l
- Adapt mstflint-s390_arch.patch to work with s390 and s390x
* Fri Mar 31 2017 nmoreychaisemartin@suse.com
- Update to v4.6.0-1, No info of changes available (fate#321683).
- Adapt patches to changed sources.
- Support build outside of SCM.
* Mon Mar 20 2017 pth@suse.de
- Update to 4.5.0-1.17.g8a0c39d, No info of changes available
  (fate#321683).
- Adapt mstflint-s390_arch.patch to changed sources.
- Remove mstflint-4.4.0-gcc6.patch as it isn't needed anymore.
* Wed Jun 29 2016 i@marguerite.su
- update version 4.4.0
- drop patch: mstflint-autotools.patch, not needed
- drop patch: mstflint-no_Werror.patch, not needed
- add patch: mstflint-4.4.0-gcc6.patch
  * fix boo#985145
  * fix unable to find string literal operator
- add patch: mstflint-4.4.0-implicit-declaration.patch
  * fix implicit declaration of mset_cr_access
  * neither mset_cr_access or MST_MLNXOS exists
- add patch: mstflint-4.4.0-no-date-time.patch
  * fix file-contains-date-and-time
* Mon Feb 22 2016 pth@suse.de
- Add mstflint-common_int_handling.patch to fix integer types handling
  and use common code instead of duplication. This creates two new
  headers, int_handling.h and tools_arch.h. The former has the type
  and print formatting code common to all files.
- Use date and time of .changes file to avoid useless rebuilds.
* Thu Feb 18 2016 pth@suse.de
- Update to 4.3.0 git 9b9af70 (fate#320235 bsc#66196).
- Remove mstflint-autotools.patch as it's not needed anymore.
- Generate ChangeLog from git log and include it.
- Refresh and fix mstflint-s390_arch.patch to apply cleanly.
- Build with Checksums enabled.
- Add placeholder man pages from Debian.
* Sun Mar  8 2015 p.drouand@gmail.com
- Update to version 4.0.0
  * No changelog available
- Use download Url as source
- Update mstflint-autotools.patch
* Fri Aug  8 2014 pth@suse.de
- Rename mstfint-mtcr_ul_no_static_lib to mstfint-mtcr_ul_no_static_lib.patch
  and include the patch for building and using a dynamic library
  as a source.
* Thu Jul 24 2014 pth@suse.de
- Don't install header and library and thus the devel package can
  be removed.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Fri May 16 2014 pth@suse.de
- Fix mstflint-s390_arch.patch to cover all new cases where
  architecture is checked.
- Add mstflint-no_Werror.patch because currently there are
  warnings where printf formats don't match passed vars.
* Wed May 14 2014 pth@suse.de
- Update to 3.6.0 from OFED 3.12 RC2.
- Remove patches as the code was fixed upstream:
  mstflint-fix_type-punning.patch
  aarch64-arch-detection.diff
- Adapt mstflint-s390_arch.patch to the new code.
- Remove mstflint-shared_lib.patch as it causes more work with
  few gains.
* Tue Apr 22 2014 pth@suse.de
- Add all defines needed for s390.
* Tue Mar  4 2014 pth@suse.de
- Fix mstflint-s390_arch.patch so that it applies.
* Mon Mar  3 2014 pth@suse.de
- Add all necessary defines or s390x (mstflint-s390_arch.patch).
* Mon Feb 10 2014 dmueller@suse.com
- add aarch64-arch-detection.diff: Fix aarch64 detection
* Mon Feb  3 2014 pth@suse.de
- Update to latest 3.5.0. No change log in package.
- Specify full source URL.
- Use spdx.org format for license specification
- Add mstflint-autotools.patch that modifies configure.ac so
  that autoreconf can run successfully.
- Remove configure.in as configure.ac is present.
- Create devel subpackage.
- Add mstflint-fix_type-punning.patch that fixes all cases of
  type-punning by using memcpy.
- Add COPYING and LICENSE to documentation.
* Fri Dec  7 2012 pth@suse.de
- Update to from OFED 1.5.4.1 (fate#314255)
- Remove patches that were integrated:
  mstflint-includefix.patch
  mstflint-1.4-0.6.g63179f4-connectX3.diff
* Tue Jan 10 2012 stefan.fent@suse.com
- Add Connect X3 support (bnc #732326)
* Thu Oct 28 2010 jjolly@novell.com
- Update to v1.4--0.6.g63179f4 from OFED 1.5.2
- Refreshed include error patch
* Thu Dec 11 2008 jjolly@suse.de
- Updated to package from OFED 1.4 GA
  - Added hca_self_test.ofed installation
* Tue Oct 28 2008 jjolly@suse.de
- Updated to v1.4 from OFED 1.3 rc3
* Mon Oct 27 2008 ro@suse.de
- fix build
* Fri Sep 12 2008 jjolly@suse.de
- Updated to v1.3 from OFED 1.4 RC1
* Tue Aug  7 2007 hvogel@suse.de
- Update to version from OFED 1.2c
* Thu Jul 12 2007 hvogel@suse.de
- package include/mtcr.h
* Wed Jul  4 2007 hvogel@suse.de
- Add GPL COPYING file [#288876]
* Tue Jul  3 2007 hvogel@suse.de
- Use correct git checkout from OFED 1.2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.2
